==> iFlow_2.2.0.tar.gz: iFlow/R/callback.R <==
button.cb <- function(scrolled_window, event, info)
{
    ptree.view <- info[[1]]
    action <- info[2]
    type <- info[3]
    ## Ignore double-clicks and triple-clicks 
    if (event[["button"]] == 3){
        if(event[["type"]] == "button-press"){
          if(type == "pheno")
                 pop.up.menu(event, ptree.view, action)
           else
                 pop.up.menu1(event, ptree.view, action)
           return(TRUE)
        }
    }
    return(FALSE)
}



### to make pop up menu by clicking mouse right button
note.button.cb <- function(scrolled_window, event, parms)
{
    page <- parms[1]
    content <- parms[[2]]
                                        # Ignore double-clicks and triple-clicks 
    if (event[["button"]] == 3){
        if(event[["type"]] == "button-press"){
            note.pop.up.menu(event, page, content)
            return(TRUE)
        }
    }
    return(FALSE)
}


#### to show up transformation infomation on gate/transformation view 
trans.cb <-
    function(selected, treeview)
{
 
   infolist <- NULL
   if(activeNodeName() %in% iget("tmethod")[[1]]){ 
         info <-iget("tmethod")[[3]][which(iget("tmethod")[[1]] == activeNodeName())]
         data.info <- sprintf("%s", info)
    } 
   else
   {
      data.info <- NULL
   }
    
     infolist <- c(infolist, data.info)
    
     iset("infolist", infolist)
     infoupdatePanel(iget("incon"), iget("infoview"))
 }
 

### to show up gate infomation on gate/transformation view 
 filter.cb <-
    function(selfilter, information)
{
    iset("gatelist", NULL)
    
    fcon <- information[[1]]
    filterview <- information[[2]]
    
    paths <- filterview$getSelection()$getSelectedRows()$retval
    inds <- sapply(paths, gtkTreePathGetIndices)
    
    info1 <- names(.guiEnv$Gate.list)[inds+1]
    gt <- .guiEnv$Gate.list[[inds+1]]
   
    # funcions in filterInfo.R
    if(gt@filterId == "defaultRectangleGate")
         ans <- recinfo(gt) 
    
    if(gt@filterId == "defaultQuadGate")
         ans<- quadinfo(gt)
       
    if(gt@filterId ==  "defaultLymphFilter")
         ans<- lymphinfo(gt)   
    
    if(gt@filterId ==  "defaultKmeansFilter")
         ans<- kmeaninfo(gt)
     
     if(gt@filterId == "defaultNorm2Filter")
         ans<- norminfo(gt)  
       
     if(gt@filterId == "defaultCurv1Filter")
     	  ans<- curv1info(gt)    
  
     if(gt@filterId == "defaultCurv2Filter")
     	  ans<- curv2info(gt)
     	     
     if(gt@filterId == "defaultPolygonGate")
         ans <- polyinfo(gt)
       
     if(slotNames(gt)[1] == "filters")
               ans <- cominfo(gt)
            
     data.info <-sprintf("%s => %s", info1, ans) 
    
    
    iset("gatelist", data.info)
    gateupdatePanel(iget("gatecon"), iget("gateview"))
  
}


page.export.cb <- function(second.item, content)
{
    
    dialog <- gtkFileChooserDialog("Enter a file name", iget("window"), "save", "gtk-cancel", GtkResponseType["cancel"], "gtk-save", GtkResponseType["accept"])
    if (dialog$run() == GtkResponseType["accept"]){
        filename <- dialog$getFilename()
        write.table(content, filename, row.names=F, sep="/t") 
    }
    dialog$destroy()
}


page.remove.cb <- function(first.item, page)
{
    iget("notebook")$removePage(page)   
}


### for help menu
help.cb <-
    function(sel, help)
{
    con <- help[[1]]
    plotview <- help[[2]]
    hcon <- help[[3]]
    
    
    paths <- plotview$getSelection()$getSelectedRows()$retval
    inds <- sapply(paths, gtkTreePathGetIndices)
    
    insert.text(inds, hcon)
    
}

help.filter.cb <-
    function(sel, help)
{
    con <- help[[1]]
    plotview <- help[[2]]
    hcon <- help[[3]]
    
    
    paths <- plotview$getSelection()$getSelectedRows()$retval
    inds <- sapply(paths, gtkTreePathGetIndices)
    
    type <- "filter"
    insert.text(inds, hcon, type = "filter")
    
}

#### backgating menu buttons 

add.cb <-
    function(but, act)
{
    view <- act[[1]]
    rdf.sel <- act[[2]]
    
    inds<-getSelectedIndices(view)
    gates <- names(.guiEnv$Gate.list[inds])  	    
    rdf.sel$appendRows(data.frame(cols=gates))	    
    	    
}

remove.cb <-
      function(but.lf, act)
{
    view1 <- act[[1]]
    rdf.sel <- act[[2]]
    
    inds<-getSelectedIndices(view1)
    
    rdf.left <-rdf.sel[-inds, ]
    as.vector(rdf.left)
    
    rdf.sel$setFrame(data.frame(cols = rdf.left))
}

==> iFlow_2.6.0.tar.gz: iFlow/R/callback.R <==
button.cb <- function(scrolled_window, event, info)
{
    ptree.view <- info[[1]]
    action <- info[2]
    type <- info[3]
    ## Ignore double-clicks and triple-clicks 
    if (event[["button"]] == 3){
        if(event[["type"]] == "button-press"){
          if(type == "pheno")
                 pop.up.menu(event, ptree.view, action)
           else
                 pop.up.menu1(event, ptree.view, action)
           return(TRUE)
        }
    }
    return(FALSE)
}



### to make pop up menu by clicking mouse right button
note.button.cb <- function(scrolled_window, event, parms)
{
    page <- parms[1]
    content <- parms[[2]]
                                        # Ignore double-clicks and triple-clicks 
    if (event[["button"]] == 3){
        if(event[["type"]] == "button-press"){
            note.pop.up.menu(event, page, content)
            return(TRUE)
        }
    }
    return(FALSE)
}


#### to show up transformation infomation on gate/transformation view 
trans.cb <-
    function(selected, treeview)
{
   wf <- activeWorkflow()
   nm <- activeNodeName()
   
   infolist <- NULL
   if(class(wf[[nm]]) == "transformView")	
   {  	   
      #if(activeNodeName() %in% iget("tmethod")[[1]]){ 
         info <-iget("tmethod")[[3]][which(iget("tmethod")[[1]] == activeNodeName())]
         data.info <- sprintf("%s", info)
      } 
   else
   {
      data.info <- NULL
   }
    
     infolist <- c(infolist, data.info)
    
     iset("infolist", infolist)
     infoupdatePanel(iget("incon"), iget("infoview"))
 }
 

### to show up gate infomation on gate/transformation view 
 filter.cb <-                                 
     function(selfilter, information)
{
    iset("gatelist", NULL)
    
    fcon <- information[[1]]
    filterview <- information[[2]]
    
    paths <- filterview$getSelection()$getSelectedRows()$retval
    inds <- sapply(paths, gtkTreePathGetIndices)
    
    info1 <- names(.guiEnv$Gate.list)[inds+1]
    gt <- .guiEnv$Gate.list[[inds+1]]
   
    # funcions in filterInfo.R
    if(class(gt) == "rectangleGate")
         ans <- recinfo(gt) 
    
    if(class(gt) == "rangeFilter")
         ans <- rangeinfo(gt)
 
    if(class(gt) == "quadGate")
         ans<- quadinfo(gt)
       
    if(class(gt) ==  "lymphFilter")
         ans<- lymphinfo(gt)   
    
    if(class(gt) ==  "kmeansFilter")
         ans<- kmeaninfo(gt)
     
     if(class(gt) == "norm2Filter")
         ans<- norminfo(gt)  
       
     if(class(gt) == "curv1Filter")
     	  ans<- curv1info(gt)    
  
     if(class(gt) == "curv2Filter")
     	  ans<- curv2info(gt)
     	     
     if(class(gt) == "polygonGate")
         ans <- polyinfo(gt)
       
     if(slotNames(gt)[1] == "filters")
               ans <- cominfo(gt)
            
     data.info <-sprintf("%s => %s", info1, ans) 
    
    
    iset("gatelist", data.info)
    gateupdatePanel(iget("gatecon"), iget("gateview"))
  
}

export.inds.cb <- function(button2, content)
{
   
    cur_node <- content[[1]]
    
    wf <-activeWorkflow()
    nm <- names(wf[[cur_node]]@indices)
    
    lng <- length(wf[[cur_node]]@indices)
    for(i in 1:(lng-1))
    {
      n_col <- max(length(wf[[cur_node]]@indices[[i]]), length(wf[[cur_node]]@indices[[i+1]]))
    } 	
    
    
    dt <- array(FALSE, dim=c(n_col, length(nm)))
    
    for(i in 1:lng)
    {
           dt[1:length(wf[[cur_node]]@indices[[i]]) ,i] <- wf[[cur_node]]@indices[[i]]
           if(length(wf[[cur_node]]@indices[[i]]) < n_col)
           	   dt[length(wf[[cur_node]]@indices[[i]]):n_col, i] <- "NO POINTS"
    } 	    
    
    colnames(dt) <- nm
    frame <- as.data.frame(dt)
    
    dialog <- gtkFileChooserDialog("Enter a file name", iget("window"), "save", "gtk-cancel", GtkResponseType["cancel"], "gtk-save", GtkResponseType["accept"])
    if (dialog$run() == GtkResponseType["accept"]){
        filename <- dialog$getFilename()
        write.table(frame, filename, row.names=T, sep=" ") 
    }
    dialog$destroy()
  
	
}	

page.export.cb <- function(second.item, content)
{
    
    dialog <- gtkFileChooserDialog("Enter a file name", iget("window"), "save", "gtk-cancel", GtkResponseType["cancel"], "gtk-save", GtkResponseType["accept"])
    if (dialog$run() == GtkResponseType["accept"]){
        filename <- dialog$getFilename()
        write.table(content, filename, row.names=F, sep="/t") 
    }
    dialog$destroy()
}


page.remove.cb <- function(first.item, page)
{
    iget("notebook")$removePage(page)   
}


### for help menu
help.cb <-
    function(sel, help)
{
    con <- help[[1]]
    plotview <- help[[2]]
    hcon <- help[[3]]
    
    
    paths <- plotview$getSelection()$getSelectedRows()$retval
    inds <- sapply(paths, gtkTreePathGetIndices)
    
    insert.text(inds, hcon)
    
}

help.filter.cb <-
    function(sel, help)
{
    con <- help[[1]]
    plotview <- help[[2]]
    hcon <- help[[3]]
    
    
    paths <- plotview$getSelection()$getSelectedRows()$retval
    inds <- sapply(paths, gtkTreePathGetIndices)
    
    type <- "filter"
    insert.text(inds, hcon, type = "filter")
    
}

#### backgating menu buttons 

add.cb <-
    function(but, act)
{
    view <- act[[1]]
    rdf.sel <- act[[2]]
    
    inds<-getSelectedIndices(view)
    gates <- names(.guiEnv$Gate.list[inds])  	    
    rdf.sel$appendRows(data.frame(cols=gates))	    
    	    
}

remove.cb <-
      function(but.lf, act)
{
    view1 <- act[[1]]
    rdf.sel <- act[[2]]
    
    inds<-getSelectedIndices(view1)
    
    rdf.left <-rdf.sel[-inds, ]
    as.vector(rdf.left)
    
    rdf.sel$setFrame(data.frame(cols = rdf.left))
}
